@@ -1,6 +1,8 @@
 """Access the Daymet database for both single single pixel and gridded queries."""
+import functools
 import io
 import itertools
+from ssl import SSLContext
 from typing import Callable, Dict, Iterable, List, Optional, Tuple, Union
 
 import async_retriever as ar
@@ -16,7 +18,9 @@ from .exceptions import InvalidInputRange, InvalidInputType
 from .pet import potential_et
 
 DEF_CRS = "epsg:4326"
-DATE_REQ = "%Y-%m-%dT%H:%M:%SZ"
+DATE_FMT = "%Y-%m-%dT%H:%M:%SZ"
+EXPIRE = -1
+MAX_CONN = 10
 
 
 def get_bycoords(
@@ -28,7 +32,10 @@ def get_bycoords(
     time_scale: str = "daily",
     pet: Optional[str] = None,
     pet_params: Optional[Dict[str, float]] = None,
-) -> xr.Dataset:
+    ssl: Union[SSLContext, bool, None] = None,
+    expire_after: float = EXPIRE,
+    disable_caching: bool = False,
+) -> pd.DataFrame:
     """Get point-data from the Daymet database at 1-km resolution.
 
     This function uses THREDDS data service to get the coordinates
@@ -69,6 +76,13 @@ def get_bycoords(
     pet_params : dict, optional
         Model-specific parameters as a dictionary that is passed to the PET function.
         Defaults to ``None``.
+    ssl : bool or SSLContext, optional
+        SSLContext to use for the connection, defaults to None. Set to False to disable
+        SSL cetification verification.
+    expire_after : int, optional
+        Expiration time for response caching in seconds, defaults to -1 (never expire).
+    disable_caching : bool, optional
+        If ``True``, disable caching requests, defaults to False.
 
     Returns
     -------
@@ -80,7 +94,13 @@ def get_bycoords(
     >>> import pydaymet as daymet
     >>> coords = (-1431147.7928, 318483.4618)
     >>> dates = ("2000-01-01", "2000-12-31")
-    >>> clm = daymet.get_bycoords(coords, dates, crs="epsg:3542", pet="hargreaves_samani")
+    >>> clm = daymet.get_bycoords(
+    ...     coords,
+    ...     dates,
+    ...     crs="epsg:3542",
+    ...     pet="hargreaves_samani",
+    ...     ssl=False
+    ... )
     >>> clm["pet (mm/day)"].mean()
     3.713
 
@@ -109,11 +129,18 @@ def get_bycoords(
     )
     url_kwd_list = [tuple(zip(*u)) for u in url_kwds]
 
+    retrieve = functools.partial(
+        ar.retrieve_binary,
+        max_workers=MAX_CONN,
+        ssl=ssl,
+        disable=disable_caching,
+        expire_after=expire_after,
+    )
     clm = pd.concat(
         (
             pd.concat(
                 pd.read_csv(io.BytesIO(r), parse_dates=[0], usecols=[0, 3], index_col=[0])
-                for r in ar.retrieve(u, "binary", request_kwds=k, max_workers=8)
+                for r in retrieve(u, k)
             )
             for u, k in url_kwd_list
         ),
@@ -140,6 +167,9 @@ def get_bygeom(
     time_scale: str = "daily",
     pet: Optional[str] = None,
     pet_params: Optional[Dict[str, float]] = None,
+    ssl: Union[SSLContext, bool, None] = None,
+    expire_after: float = EXPIRE,
+    disable_caching: bool = False,
 ) -> xr.Dataset:
     """Get gridded data from the Daymet database at 1-km resolution.
 
@@ -177,6 +207,13 @@ def get_bygeom(
     pet_params : dict, optional
         Model-specific parameters as a dictionary that is passed to the PET function.
         Defaults to ``None``.
+    ssl : bool or SSLContext, optional
+        SSLContext to use for the connection, defaults to None. Set to False to disable
+        SSL cetification verification.
+    expire_after : int, optional
+        Expiration time for response caching in seconds, defaults to -1 (never expire).
+    disable_caching : bool, optional
+        If ``True``, disable caching requests, defaults to False.
 
     Returns
     -------
@@ -222,8 +259,18 @@ def get_bygeom(
     )
 
     try:
-        clm = xr.open_mfdataset(
-            (io.BytesIO(r) for r in ar.retrieve(urls, "binary", request_kwds=kwds, max_workers=8)),
+        clm: xr.Dataset = xr.open_mfdataset(  # type: ignore
+            (
+                io.BytesIO(r)
+                for r in ar.retrieve_binary(
+                    urls,
+                    request_kwds=list(kwds),
+                    max_workers=MAX_CONN,
+                    ssl=ssl,
+                    disable=disable_caching,
+                    expire_after=expire_after,
+                )
+            ),
             engine="scipy",
             coords="minimal",
         )
@@ -268,7 +315,8 @@ def get_bygeom(
             clm[v].attrs["crs"] = daymet_crs
             clm[v].attrs["nodatavals"] = (0.0,)
 
-    return geoutils.xarray_geomask(clm, _geometry, DEF_CRS)
+    masked: xr.Dataset = geoutils.xarray_geomask(clm, _geometry, DEF_CRS)
+    return masked
 
 
 def _get_filename(
@@ -347,8 +395,8 @@ def _coord_urls(
                         "var": v,
                         "longitude": f"{lon}",
                         "latitude": f"{lat}",
-                        "time_start": s.strftime(DATE_REQ),
-                        "time_end": e.strftime(DATE_REQ),
+                        "time_start": s.strftime(DATE_FMT),
+                        "time_end": e.strftime(DATE_FMT),
                         "accept": "csv",
                     }
                 },
@@ -412,8 +460,8 @@ def _gridded_urls(
                     "south": f"{south}",
                     "disableProjSubset": "on",
                     "horizStride": "1",
-                    "time_start": s.strftime(DATE_REQ),
-                    "time_end": e.strftime(DATE_REQ),
+                    "time_start": s.strftime(DATE_FMT),
+                    "time_end": e.strftime(DATE_FMT),
                     "timeStride": "1",
                     "addLatLon": "true",
                     "accept": "netcdf",
