@@ -31,19 +31,23 @@ class TestByCoords:
         [("hargreaves_samani", 3.713), ("priestley_taylor", 3.175), ("penman_monteith", 3.472)],
     )
     def test_pet(self, method, expected):
-        clm = daymet.get_bycoords(COORDS, DATES, crs=ALT_CRS, pet=method)
+        clm = daymet.get_bycoords(COORDS, DATES, crs=ALT_CRS, pet=method, ssl=False)
         assert abs(clm["pet (mm/day)"].mean() - expected) < SMALL
 
     def test_daily(self):
-        clm = daymet.get_bycoords(COORDS, DATES, variables=VAR, crs=ALT_CRS)
+        clm = daymet.get_bycoords(COORDS, DATES, variables=VAR, crs=ALT_CRS, ssl=False)
         assert abs(clm["prcp (mm/day)"].mean() - 1.005) < SMALL
 
     def test_monthly(self):
-        clm = daymet.get_bycoords(COORDS, YEAR, variables=VAR, crs=ALT_CRS, time_scale="monthly")
+        clm = daymet.get_bycoords(
+            COORDS, YEAR, variables=VAR, crs=ALT_CRS, time_scale="monthly", ssl=False
+        )
         assert abs(clm["tmin (degrees C)"].mean() - 11.435) < SMALL
 
     def test_annual(self):
-        clm = daymet.get_bycoords(COORDS, YEAR, variables=VAR, crs=ALT_CRS, time_scale="annual")
+        clm = daymet.get_bycoords(
+            COORDS, YEAR, variables=VAR, crs=ALT_CRS, time_scale="annual", ssl=False
+        )
         assert abs(clm["tmin (degrees C)"].mean() - 11.458) < SMALL
 
 
@@ -53,30 +57,34 @@ class TestByGeom:
         [("hargreaves_samani", 0.453), ("priestley_taylor", 0.119), ("penman_monteith", 0.627)],
     )
     def test_pet(self, method, expected):
-        clm = daymet.get_bygeom(GEOM, DAY, pet=method)
+        clm = daymet.get_bygeom(GEOM, DAY, pet=method, ssl=False)
         assert abs(clm.pet.mean().values - expected) < SMALL
 
     def test_bounds(self):
-        prcp = daymet.get_bygeom(GEOM.bounds, DAY)
+        prcp = daymet.get_bygeom(GEOM.bounds, DAY, ssl=False)
         assert abs(prcp.prcp.mean().values - 3.4999) < SMALL
 
     def test_daily(self):
-        daily = daymet.get_bygeom(GEOM, DAY, variables=VAR)
+        daily = daymet.get_bygeom(GEOM, DAY, variables=VAR, ssl=False)
         assert abs(daily.tmin.mean().values - (-9.421)) < SMALL
 
     def test_monthly(self):
-        monthly = daymet.get_bygeom(GEOM, YEAR, variables=VAR, time_scale="monthly")
+        monthly = daymet.get_bygeom(GEOM, YEAR, variables=VAR, time_scale="monthly", ssl=False)
         assert abs(monthly.tmin.mean().values - 1.311) < SMALL
 
     def test_annual(self):
-        annual = daymet.get_bygeom(GEOM, YEAR, variables=VAR, time_scale="annual")
+        annual = daymet.get_bygeom(GEOM, YEAR, variables=VAR, time_scale="annual", ssl=False)
         assert abs(annual.tmin.mean().values - 1.361) < SMALL
 
     def test_region(self):
         hi_ext = (-160.3055, 17.9539, -154.7715, 23.5186)
         pr_ext = (-67.9927, 16.8443, -64.1195, 19.9381)
-        hi = daymet.get_bygeom(hi_ext, YEAR, variables=VAR, region="hi", time_scale="annual")
-        pr = daymet.get_bygeom(pr_ext, YEAR, variables=VAR, region="pr", time_scale="annual")
+        hi = daymet.get_bygeom(
+            hi_ext, YEAR, variables=VAR, region="hi", time_scale="annual", ssl=False
+        )
+        pr = daymet.get_bygeom(
+            pr_ext, YEAR, variables=VAR, region="pr", time_scale="annual", ssl=False
+        )
 
         assert (
             abs(hi.prcp.mean().values - 1035.233) < SMALL
@@ -106,6 +114,7 @@ class TestCLI:
                 *list(tlz.concat([["-v", v] for v in VAR])),
                 "-s",
                 save_dir,
+                "--disable_ssl",
             ],
         )
         if geo_gpkg.is_dir():
@@ -137,6 +146,7 @@ class TestCLI:
                 *list(tlz.concat([["-v", v] for v in VAR])),
                 "-s",
                 save_dir,
+                "--disable_ssl",
             ],
         )
         runner.invoke(
@@ -147,6 +157,7 @@ class TestCLI:
                 *list(tlz.concat([["-v", v] for v in VAR])),
                 "-s",
                 save_dir,
+                "--disable_ssl",
             ],
         )
         Path(coord_csv).unlink()
